self.__BUILD_MANIFEST=function(a,s,c,e,t,p,i,n,d,f,b,u){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[a,s,"static/chunks/pages/index-34f33eba8b802804.js"],"/_error":["static/chunks/pages/_error-a4ba2246ff8fb532.js"],"/app/bridges/openon":[a,s,c,e,p,i,n,"static/chunks/pages/app/bridges/openon-d549cb748d0c33cb.js"],"/app/bridges/setup":[a,s,c,e,p,i,d,"static/chunks/pages/app/bridges/setup-5ac5af8b35a260d4.js"],"/app/data":[a,t,s,e,"static/chunks/549-19501f67a5b0ace4.js","static/chunks/pages/app/data-1245ef0d8c9e70c4.js"],"/app/notification":[a,s,i,"static/chunks/pages/app/notification-521e9fb13fe41dc4.js"],"/app/player/audio":[a,t,f,s,c,b,u,"static/chunks/pages/app/player/audio-5544e8d4da5fa895.js"],"/app/player/video":[a,t,f,s,c,b,u,"static/chunks/pages/app/player/video-e33c1f793be3f872.js"],"/app/settings":[a,t,s,c,e,p,n,d,"static/chunks/377-9936de8ec9156df4.js","static/chunks/pages/app/settings-14c24cf4515ac9fc.js"],sortedPages:["/","/_app","/_error","/app/bridges/openon","/app/bridges/setup","/app/data","/app/notification","/app/player/audio","/app/player/video","/app/settings"]}}("static/chunks/b2e984c5-1b480e34f3250640.js","static/chunks/413-9c11213828800a89.js","static/chunks/356-4a25b50e7500bd9b.js","static/chunks/316-226d8ba79338d06d.js","static/chunks/29107295-fbcfe2172188e46f.js","static/chunks/699-f14c98003441d35c.js","static/chunks/669-e83532188aad81cf.js","static/chunks/713-735e777f92b62d1d.js","static/chunks/767-716e9d0074432d47.js","static/chunks/75fc9c18-e61c2e0d9c9a0957.js","static/chunks/67-75f2d2f8aba2ea50.js","static/chunks/173-0447a9572d5341a0.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();